@@ -8,14 +8,10 @@ Acceptors handle the acceptance step.
 
 
 from .acceptor import (
-    AcceptorResult,
     Acceptor,
+    AcceptorResult,
     SimpleFunctionAcceptor,
-    UniformAcceptor,
     StochasticAcceptor,
+    UniformAcceptor,
 )
-from .pdf_norm import (
-    pdf_norm_from_kernel,
-    pdf_norm_max_found,
-    ScaledPDFNorm,
-)
+from .pdf_norm import ScaledPDFNorm, pdf_norm_from_kernel, pdf_norm_max_found
