@@ -1,67 +1,69 @@
 """
-Distance functions
-==================
+Distances
+=========
 
-Distance functions measure closeness of observed and sampled data. This
-module implements various commonly used distance functions for ABC, featuring
-a few advanced concepts.
+Distance functions or metrics measure closeness of observed and sampled data.
+This module implements various commonly used distance functions for ABC,
+featuring a few advanced concepts.
 
 For custom distance functions, either pass a plain function to ABCSMC, or
 subclass the pyabc.Distance class.
 """
 
+from .aggregate import AdaptiveAggregatedDistance, AggregatedDistance
 from .base import (
+    AcceptAllDistance,
     Distance,
     NoDistance,
-    AcceptAllDistance,
     SimpleFunctionDistance,
     to_distance,
 )
 from .distance import (
-    PNormDistance,
-    AdaptivePNormDistance,
-    InfoWeightedPNormDistance,
-    AggregatedDistance,
-    AdaptiveAggregatedDistance,
-    ZScoreDistance,
-    PCADistance,
+    DistanceWithMeasureList,
     MinMaxDistance,
+    PCADistance,
     PercentileDistance,
     RangeEstimatorDistance,
-    DistanceWithMeasureList,
-)
-from .scale import (
-    median_absolute_deviation,
-    mad,
-    mean_absolute_deviation,
-    standard_deviation,
-    std,
-    bias,
-    root_mean_square_deviation,
-    rmsd,
-    std_or_rmsd,
-    median_absolute_deviation_to_observation,
-    mado,
-    mad_or_cmad,
-    pcmad,
-    mean_absolute_deviation_to_observation,
-    combined_median_absolute_deviation,
-    cmad,
-    combined_mean_absolute_deviation,
-    standard_deviation_to_observation,
-    span,
-    mean,
-    median,
+    ZScoreDistance,
 )
 from .kernel import (
-    StochasticKernel,
     SCALE_LIN,
     SCALE_LOG,
-    SimpleFunctionKernel,
-    NormalKernel,
-    IndependentNormalKernel,
-    IndependentLaplaceKernel,
     BinomialKernel,
-    PoissonKernel,
+    IndependentLaplaceKernel,
+    IndependentNormalKernel,
     NegativeBinomialKernel,
+    NormalKernel,
+    PoissonKernel,
+    SimpleFunctionKernel,
+    StochasticKernel,
+)
+from .ot import SlicedWassersteinDistance, WassersteinDistance
+from .pnorm import (
+    AdaptivePNormDistance,
+    InfoWeightedPNormDistance,
+    PNormDistance,
+)
+from .scale import (
+    bias,
+    cmad,
+    combined_mean_absolute_deviation,
+    combined_median_absolute_deviation,
+    mad,
+    mad_or_cmad,
+    mado,
+    mean,
+    mean_absolute_deviation,
+    mean_absolute_deviation_to_observation,
+    median,
+    median_absolute_deviation,
+    median_absolute_deviation_to_observation,
+    pcmad,
+    rmsd,
+    root_mean_square_deviation,
+    span,
+    standard_deviation,
+    standard_deviation_to_observation,
+    std,
+    std_or_rmsd,
 )
