@@ -1,8 +1,8 @@
 """Sampling util functions."""
 
-from .base import Sample
+from ..population import Sample
 
 
 def any_particle_preliminary(sample: Sample) -> bool:
     """Determine whether any particle in that sample is preliminary."""
-    return any(particle.preliminary for particle in sample.particles)
+    return any(particle.preliminary for particle in sample.all_particles)
