@@ -1,6 +1,7 @@
+import tempfile
+
 import numpy as np
 import pandas as pd
-import tempfile
 
 import pyabc
 from pyabc.acceptor import AcceptorResult
@@ -21,8 +22,14 @@ def test_simple_function_acceptor():
 
     acceptor = pyabc.SimpleFunctionAcceptor(dummy_accept)
 
-    ret = acceptor(distance_function=distance, eps=lambda t: 0.1,
-                   x=x, x_0=y, t=0, par=None)
+    ret = acceptor(
+        distance_function=distance,
+        eps=lambda t: 0.1,
+        x=x,
+        x_0=y,
+        t=0,
+        par=None,
+    )
 
     assert isinstance(ret, AcceptorResult)
     assert ret.distance == 3
@@ -33,8 +40,7 @@ def test_simple_function_acceptor():
         return {'s0': par['p0'] + 1, 's1': 42}
 
     prior = pyabc.Distribution(p0=pyabc.RV('uniform', -5, 10))
-    abc = pyabc.ABCSMC(
-        model, prior, distance, population_size=2)
+    abc = pyabc.ABCSMC(model, prior, distance, population_size=2)
     abc.new(pyabc.create_sqlite_db_id(), model({'p0': 1}))
     h = abc.run(max_nr_populations=2)
 
@@ -44,6 +50,7 @@ def test_simple_function_acceptor():
 
 def test_uniform_acceptor():
     """Test the uniform acceptor."""
+
     def dist(x, x_0):
         return sum(abs(x[key] - x_0[key]) for key in x_0)
 
@@ -54,8 +61,9 @@ def test_uniform_acceptor():
     x = {'s0': 1.5}
     x_0 = {'s0': 0}
 
-    ret = acceptor(distance_function=distance,
-                   eps=eps, x=x, x_0=x_0, t=2, par=None)
+    ret = acceptor(
+        distance_function=distance, eps=eps, x=x, x_0=x_0, t=2, par=None
+    )
 
     assert ret.accept
 
@@ -63,8 +71,9 @@ def test_uniform_acceptor():
 
     acceptor = pyabc.UniformAcceptor(use_complete_history=True)
 
-    ret = acceptor(distance_function=distance,
-                   eps=eps, x=x, x_0=x_0, t=2, par=None)
+    ret = acceptor(
+        distance_function=distance, eps=eps, x=x, x_0=x_0, t=2, par=None
+    )
 
     assert not ret.accept
 
@@ -74,21 +83,23 @@ def test_stochastic_acceptor():
     # store pnorms
     pnorm_file = tempfile.mkstemp(suffix=".json")[1]
     acceptor = pyabc.StochasticAcceptor(
-        pdf_norm_method=pyabc.pdf_norm_max_found,
-        log_file=pnorm_file)
+        pdf_norm_method=pyabc.pdf_norm_max_found, log_file=pnorm_file
+    )
     eps = pyabc.Temperature(initial_temperature=1)
     distance = pyabc.IndependentNormalKernel(var=np.array([1, 1]))
 
     def model(par):
         return {'s0': par['p0'] + np.array([0.3, 0.7])}
+
     x_0 = {'s0': np.array([0.4, -0.6])}
 
     # just run
     prior = pyabc.Distribution(p0=pyabc.RV('uniform', -1, 2))
-    abc = pyabc.ABCSMC(model, prior, distance, eps=eps,
-                       acceptor=acceptor, population_size=10)
+    abc = pyabc.ABCSMC(
+        model, prior, distance, eps=eps, acceptor=acceptor, population_size=10
+    )
     abc.new(pyabc.create_sqlite_db_id(), x_0)
-    h = abc.run(max_nr_populations=1, minimum_epsilon=1.)
+    h = abc.run(max_nr_populations=1, minimum_epsilon=1.0)
 
     # check pnorms
     pnorms = pyabc.storage.load_dict_from_json(pnorm_file)
@@ -99,31 +110,40 @@ def test_stochastic_acceptor():
     # use no initial temperature and adaptive c
     acceptor = pyabc.StochasticAcceptor()
     eps = pyabc.Temperature()
-    abc = pyabc.ABCSMC(model, prior, distance, eps=eps,
-                       acceptor=acceptor, population_size=20)
+    abc = pyabc.ABCSMC(
+        model, prior, distance, eps=eps, acceptor=acceptor, population_size=20
+    )
     abc.new(pyabc.create_sqlite_db_id(), x_0)
     abc.run(max_nr_populations=3)
 
 
 def test_pdf_norm_methods_integration():
     """Test integration of pdf normalization methods in ABCSMC."""
+
     def model(par):
         return {'s0': par['p0'] + np.array([0.3, 0.7])}
 
     x_0 = {'s0': np.array([0.4, -0.6])}
 
-    for pdf_norm in [pyabc.pdf_norm_max_found,
-                     pyabc.pdf_norm_from_kernel,
-                     pyabc.ScaledPDFNorm(),
-                     ]:
+    for pdf_norm in [
+        pyabc.pdf_norm_max_found,
+        pyabc.pdf_norm_from_kernel,
+        pyabc.ScaledPDFNorm(),
+    ]:
         # just run
         acceptor = pyabc.StochasticAcceptor(pdf_norm_method=pdf_norm)
         eps = pyabc.Temperature()
         distance = pyabc.IndependentNormalKernel(var=np.array([1, 1]))
         prior = pyabc.Distribution(p0=pyabc.RV('uniform', -1, 2))
 
-        abc = pyabc.ABCSMC(model, prior, distance, eps=eps, acceptor=acceptor,
-                           population_size=20)
+        abc = pyabc.ABCSMC(
+            model,
+            prior,
+            distance,
+            eps=eps,
+            acceptor=acceptor,
+            population_size=20,
+        )
         abc.new(pyabc.create_sqlite_db_id(), x_0)
         abc.run(max_nr_populations=3)
 
@@ -133,9 +153,7 @@ def test_pdf_norm_methods():
     # preparations
 
     def _get_weighted_distances():
-        return pd.DataFrame({
-            'distance': [1, 2, 3, 4],
-            'w': [2, 1, 1, 0]})
+        return pd.DataFrame({'distance': [1, 2, 3, 4], 'w': [2, 1, 1, 0]})
 
     pdf_norm_args = {
         'kernel_val': 42,
