@@ -1,19 +1,21 @@
 """Execute petab test suite."""
 
-import petabtests
+import logging
 import os
 import sys
+
+import petabtests
 import pytest
 from _pytest.outcomes import Skipped
-import logging
 
 import pyabc
 
 try:
-    import petab
-    import pyabc.petab
     import amici.petab_import
     import amici.petab_objective
+    import petab
+
+    import pyabc.petab
 except ImportError:
     pass
 
@@ -44,11 +46,13 @@ def execute_case(case):
     try:
         _execute_case(case)
     except Exception as e:
-        if isinstance(e, NotImplementedError) \
-                or "timepoint specific" in str(e):
+        if isinstance(e, NotImplementedError) or "timepoint specific" in str(
+            e
+        ):
             logger.info(
                 f"Case {case} expectedly failed. Required functionality is "
-                f"not implemented: {e}")
+                f"not implemented: {e}"
+            )
             pytest.skip(str(e))
         else:
             raise e
@@ -91,7 +95,8 @@ def _execute_case(case):
 
     # import to pyabc
     importer = pyabc.petab.AmiciPetabImporter(
-        petab_problem, amici_model, solver)
+        petab_problem, amici_model, solver
+    )
     model = importer.create_model(return_rdatas=True)
 
     # simulate
@@ -104,32 +109,42 @@ def _execute_case(case):
     rdatas = ret['rdatas']
     chi2 = sum(rdata['chi2'] for rdata in rdatas)
     simulation_df = amici.petab_objective.rdatas_to_measurement_df(
-        rdatas, amici_model, importer.petab_problem.measurement_df)
+        rdatas, amici_model, importer.petab_problem.measurement_df
+    )
     petab.check_measurement_df(
-        simulation_df, importer.petab_problem.observable_df)
+        simulation_df, importer.petab_problem.observable_df
+    )
     simulation_df = simulation_df.rename(
-        columns={petab.MEASUREMENT: petab.SIMULATION})
+        columns={petab.MEASUREMENT: petab.SIMULATION}
+    )
     simulation_df[petab.TIME] = simulation_df[petab.TIME].astype(int)
 
     # check if matches
     chi2s_match = petabtests.evaluate_chi2(chi2, gt_chi2, tol_chi2)
     llhs_match = petabtests.evaluate_llh(llh, gt_llh, tol_llh)
     simulations_match = petabtests.evaluate_simulations(
-        [simulation_df], gt_simulation_dfs, tol_simulations)
+        [simulation_df], gt_simulation_dfs, tol_simulations
+    )
 
     # log matches
-    logger.log(logging.INFO if chi2s_match else logging.ERROR,
-               f"CHI2: simulated: {chi2}, expected: {gt_chi2},"
-               f" match = {chi2s_match}")
-    logger.log(logging.INFO if simulations_match else logging.ERROR,
-               f"LLH: simulated: {llh}, expected: {gt_llh}, "
-               f"match = {llhs_match}")
-    logger.log(logging.INFO if simulations_match else logging.ERROR,
-               f"Simulations: match = {simulations_match}")
+    logger.log(
+        logging.INFO if chi2s_match else logging.ERROR,
+        f"CHI2: simulated: {chi2}, expected: {gt_chi2},"
+        f" match = {chi2s_match}",
+    )
+    logger.log(
+        logging.INFO if simulations_match else logging.ERROR,
+        f"LLH: simulated: {llh}, expected: {gt_llh}, " f"match = {llhs_match}",
+    )
+    logger.log(
+        logging.INFO if simulations_match else logging.ERROR,
+        f"Simulations: match = {simulations_match}",
+    )
 
     if not all([llhs_match, chi2s_match, simulations_match]):
         logger.error(f"Case {case} failed.")
-        raise AssertionError(f"Case {case}: Test results do not match "
-                             "expectations")
+        raise AssertionError(
+            f"Case {case}: Test results do not match " "expectations"
+        )
 
     logger.info(f"Case {case} passed.")
